@@ -6,6 +6,7 @@ vcspull.cli
 """
 import argparse
 import logging
+import textwrap
 
 from libvcs.__about__ import __version__ as libvcs_version
 
@@ -15,9 +16,26 @@ from .sync import create_sync_subparser, sync
 
 log = logging.getLogger(__name__)
 
+SYNC_DESCRIPTION = textwrap.dedent(
+    """
+    sync vcs repos
+
+    examples:
+      vcspull sync "*"
+      vcspull sync "django-*"
+      vcspull sync "django-*" flask
+      vcspull sync -c ./myrepos.yaml "*"
+      vcspull sync -c ./myrepos.yaml myproject
+"""
+).strip()
+
 
 def create_parser():
-    parser = argparse.ArgumentParser(prog="vcspull")
+    parser = argparse.ArgumentParser(
+        prog="vcspull",
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        description=SYNC_DESCRIPTION,
+    )
     parser.add_argument(
         "--version",
         "-V",
@@ -26,19 +44,26 @@ def create_parser():
     )
     parser.add_argument(
         "--log-level",
+        metavar="level",
         action="store",
         default="INFO",
-        help="Log level (DEBUG, INFO, WARNING, ERROR, CRITICAL)",
+        help="log level (debug, info, warning, error, critical)",
     )
+
     subparsers = parser.add_subparsers(dest="subparser_name")
-    sync_parser = subparsers.add_parser("sync")
+    sync_parser = subparsers.add_parser(
+        "sync",
+        help="synchronize repos",
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        description=SYNC_DESCRIPTION,
+    )
     create_sync_subparser(sync_parser)
 
-    return parser
+    return parser, sync_parser
 
 
 def cli(args=None):
-    parser = create_parser()
+    parser, sync_parser = create_parser()
     args = parser.parse_args(args)
 
     setup_logger(log=log, level=args.log_level.upper())
@@ -51,5 +76,5 @@ def cli(args=None):
             repo_terms=args.repo_terms,
             config=args.config,
             exit_on_error=args.exit_on_error,
-            parser=parser,
+            parser=sync_parser,
         )
