@@ -21,19 +21,32 @@ NO_REPOS_FOR_TERM_MSG = 'No repo found in config(s) for "{name}"'
 
 
 def create_sync_subparser(parser: argparse.ArgumentParser) -> argparse.ArgumentParser:
-    parser.add_argument("--config", "-c", help="Specify config")
+    config_file = parser.add_argument(
+        "--config",
+        "-c",
+        metavar="config-file",
+        help="optional filepath to specify vcspull config",
+    )
     parser.add_argument(
         "repo_terms",
-        nargs="+",
-        help="Filters of repo terms, separated by spaces, supports globs / fnmatch (1)",
+        metavar="filter",
+        nargs="*",
+        help="patterns / terms of repos, accepts globs / fnmatch(3)",
     )
     parser.add_argument(
         "--exit-on-error",
         "-x",
         action="store_true",
         dest="exit_on_error",
-        help="Exit immediately when encountering an error syncing multiple repos",
+        help="exit immediately encountering error (when syncing multiple repos)",
     )
+
+    try:
+        import shtab
+
+        config_file.complete = shtab.FILE  # type: ignore
+    except ImportError:
+        pass
     return parser
 
 
@@ -45,6 +58,11 @@ def sync(
         argparse.ArgumentParser
     ] = None,  # optional so sync can be unit tested
 ) -> None:
+    if isinstance(repo_terms, list) and len(repo_terms) == 0:
+        if parser is not None:
+            parser.print_help()
+        sys.exit(2)
+
     if config:
         configs = load_configs([config])
     else:
