@@ -1,40 +1,47 @@
 import pathlib
 import textwrap
-from typing import Callable, List
+import typing as t
 
 import pytest
 
-import kaptan
-
-from libvcs.projects.git import GitRemote
-from libvcs.shortcuts import create_project_from_pip_url
+from libvcs._internal.shortcuts import create_project
+from libvcs.pytest_plugin import CreateProjectCallbackFixtureProtocol
+from libvcs.sync.git import GitRemote, GitSync
+from vcspull._internal.config_reader import ConfigReader
 from vcspull.cli.sync import update_repo
 from vcspull.config import extract_repos, filter_repos, load_configs
+from vcspull.types import ConfigDict
 
 from .helpers import write_config
 
 
 def test_makes_recursive(
     tmp_path: pathlib.Path,
-    git_dummy_repo_dir: pathlib.Path,
+    git_remote_repo: pathlib.Path,
 ):
     """Ensure that directories in pull are made recursively."""
-    conf = kaptan.Kaptan(handler="yaml")
-    conf.import_config(
-        textwrap.dedent(
+    conf = ConfigReader._load(
+        format="yaml",
+        content=textwrap.dedent(
             f"""
         {tmp_path}/study/myrepo:
-            my_url: git+file://{git_dummy_repo_dir}
+            my_url: git+file://{git_remote_repo}
     """
-        )
+        ),
     )
-    conf = conf.export("dict")
     repos = extract_repos(conf)
+    assert len(repos) > 0
 
-    for r in filter_repos(repos):
-        repo = create_project_from_pip_url(**r)
+    filtered_repos = filter_repos(repos, dir="*")
+    assert len(filtered_repos) > 0
+
+    for r in filtered_repos:
+        assert isinstance(r, dict)
+        repo = create_project(**r)  # type: ignore
         repo.obtain()
 
+        assert repo.dir.exists()
+
 
 def write_config_remote(
     config_path: pathlib.Path, tmp_path: pathlib.Path, config_tpl, dir, clone_name
@@ -79,14 +86,14 @@ def write_config_remote(
 )
 def test_config_variations(
     tmp_path: pathlib.Path,
-    create_git_dummy_repo: Callable[[str], pathlib.Path],
+    create_git_remote_repo: CreateProjectCallbackFixtureProtocol,
     config_tpl: str,
-    capsys: pytest.LogCaptureFixture,
-    remote_list: List[str],
-):
+    capsys: pytest.CaptureFixture[str],
+    remote_list: t.List[str],
+) -> None:
     """Test config output with variation of config formats"""
     dummy_repo_name = "dummy_repo"
-    dummy_repo = create_git_dummy_repo(dummy_repo_name)
+    dummy_repo = create_git_remote_repo(remote_repo_name=dummy_repo_name)
 
     config_file = write_config_remote(
         config_path=tmp_path / "myrepos.yaml",
@@ -103,8 +110,8 @@ def test_config_variations(
 
     for repo_dict in repos:
         repo_url = repo_dict["url"].replace("git+", "")
-        repo = update_repo(repo_dict)
-        remotes = repo.remotes() or []
+        repo: GitSync = update_repo(repo_dict)
+        remotes = repo.remotes() or {}
         remote_names = set(remotes.keys())
         assert set(remote_list).issubset(remote_names) or {"origin"}.issubset(
             remote_names
@@ -112,6 +119,7 @@ def test_config_variations(
 
         for remote_name, remote_info in remotes.items():
             current_remote = repo.remote(remote_name)
+            assert current_remote is not None
             assert current_remote.fetch_url == repo_url
 
 
@@ -147,32 +155,32 @@ def test_config_variations(
 )
 def test_updating_remote(
     tmp_path: pathlib.Path,
-    create_git_dummy_repo: Callable[[str], pathlib.Path],
+    create_git_remote_repo: CreateProjectCallbackFixtureProtocol,
     config_tpl: str,
-    has_extra_remotes,
-):
+    has_extra_remotes: bool,
+) -> None:
     """Ensure additions/changes to yaml config are reflected"""
 
     dummy_repo_name = "dummy_repo"
-    dummy_repo = create_git_dummy_repo(dummy_repo_name)
+    dummy_repo = create_git_remote_repo(remote_repo_name=dummy_repo_name)
 
     mirror_name = "mirror_repo"
-    mirror_repo = create_git_dummy_repo(mirror_name)
+    mirror_repo = create_git_remote_repo(remote_repo_name=mirror_name)
 
     repo_parent = tmp_path / "study" / "myrepo"
     repo_parent.mkdir(parents=True)
 
-    initial_config = {
+    initial_config: ConfigDict = {
+        "vcs": "git",
         "name": "myclone",
         "dir": f"{tmp_path}/study/myrepo/myclone",
-        "parent_dir": f"{tmp_path}/study/myrepo",
         "url": f"git+file://{dummy_repo}",
         "remotes": {
-            mirror_name: {
-                "name": mirror_name,
-                "fetch_url": f"git+file://{dummy_repo}",
-                "push_url": f"git+file://{dummy_repo}",
-            }
+            mirror_name: GitRemote(
+                name=mirror_name,
+                fetch_url=f"git+file://{dummy_repo}",
+                push_url=f"git+file://{dummy_repo}",
+            )
         },
     }
 
@@ -184,25 +192,30 @@ def test_updating_remote(
 
     expected_remote_url = f"git+file://{mirror_repo}"
 
-    config = initial_config | {
-        "remotes": {
-            mirror_name: GitRemote(
-                name=mirror_name,
-                fetch_url=expected_remote_url,
-                push_url=expected_remote_url,
-            )
-        }
-    }
+    expected_config: ConfigDict = initial_config.copy()
+    assert isinstance(expected_config["remotes"], dict)
+    expected_config["remotes"][mirror_name] = GitRemote(
+        name=mirror_name,
+        fetch_url=expected_remote_url,
+        push_url=expected_remote_url,
+    )
 
-    repo_dict = filter_repos([config], name="myclone")[0]
+    repo_dict = filter_repos([expected_config], name="myclone")[0]
     repo = update_repo(repo_dict)
     for remote_name, remote_info in repo.remotes().items():
-        current_remote_url = repo.remote(remote_name).fetch_url.replace("git+", "")
-        if remote_name in config["remotes"]:
-            assert (
-                config["remotes"][remote_name].fetch_url.replace("git+", "")
-                == current_remote_url
-            )
+        remote = repo.remote(remote_name)
+        if remote is not None:
+            current_remote_url = remote.fetch_url.replace("git+", "")
+            if remote_name in expected_config["remotes"]:
+                assert (
+                    expected_config["remotes"][remote_name].fetch_url.replace(
+                        "git+", ""
+                    )
+                    == current_remote_url
+                )
 
-        elif remote_name == "origin":
-            assert config["url"].replace("git+", "") == current_remote_url
+            elif remote_name == "origin" and remote_name in expected_config["remotes"]:
+                assert (
+                    expected_config["remotes"]["origin"].fetch_url.replace("git+", "")
+                    == current_remote_url
+                )
